Method: RTicker::Entry#symbol
- Defined in:
- lib/rticker/entry.rb
#symbol ⇒ Object
etc.) @description is an optional string that can give a more user-friendly description of a symbol. If a description is not provided, the symbol itself is displayed to the user. If the user provides information on having purchased an entry (for example AAPL stock), the user may specify how many via @purchase_count (in this case how many shares), and for how much via @purchase_price (in this case how much paid per share). A user can specify a negative this entry should stand apart from other entries when displayed to the user.
21 22 23 |
# File 'lib/rticker/entry.rb', line 21 def symbol @symbol end |