Class: RTicker::Separator
- Inherits:
-
Object
- Object
- RTicker::Separator
- Defined in:
- lib/rticker/separator.rb
Overview
This class is simply used to represent a separator when displaying entries to the user.
This class is simply used to represent a separator when displaying entries to the user.